@@ -109,6 +109,9 @@ def _parse_args() -> argparse.Namespace:
         type=Path,
         help='Path to a virtualenv json config to use for this action.',
     )
+    parser.add_argument(
+        '--command-launcher', help='Arguments to prepend to Python command'
+    )
     parser.add_argument(
         'original_cmd',
         nargs=argparse.REMAINDER,
@@ -200,6 +203,7 @@ def main(  # pylint: disable=too-many-arguments,too-many-branches,too-many-local
     capture_output: bool,
     touch: Optional[Path],
     working_directory: Optional[Path],
+    command_launcher: Optional[str],
     lockfile: Optional[Path],
 ) -> int:
     """Script entry point."""
@@ -258,6 +262,9 @@ def main(  # pylint: disable=too-many-arguments,too-many-branches,too-many-local
     if python_interpreter is not None:
         command = [str(root_build_dir / python_interpreter)]
 
+    if command_launcher is not None:
+        command = shlex.split(command_launcher) + command
+
     if module is not None:
         command += ['-m', module]
 
