@@ -23,7 +23,9 @@ from prompt_toolkit.completion import WordCompleter
 from pw_console.console_app import ConsoleApp
 from pw_console.get_pw_console_app import PW_CONSOLE_APP_CONTEXTVAR
 from pw_console.plugin_mixin import PluginMixin
-import pw_console.python_logging
+from pw_console.python_logging import (
+    setup_python_logging as pw_console_setup_python_logging,
+)
 from pw_console.widgets import (
     FloatingWindowPane,
     WindowPane,
@@ -42,16 +44,19 @@ class PwConsoleEmbed:
     """Embed class for customizing the console before startup."""
 
     # pylint: disable=too-many-instance-attributes
-    def __init__(self,
-                 global_vars=None,
-                 local_vars=None,
-                 loggers: Optional[Union[Dict[str, Iterable[logging.Logger]],
-                                         Iterable]] = None,
-                 test_mode=False,
-                 repl_startup_message: Optional[str] = None,
-                 help_text: Optional[str] = None,
-                 app_title: Optional[str] = None,
-                 config_file_path: Optional[Union[str, Path]] = None) -> None:
+    def __init__(
+        self,
+        global_vars=None,
+        local_vars=None,
+        loggers: Optional[
+            Union[Dict[str, Iterable[logging.Logger]], Iterable]
+        ] = None,
+        test_mode=False,
+        repl_startup_message: Optional[str] = None,
+        help_text: Optional[str] = None,
+        app_title: Optional[str] = None,
+        config_file_path: Optional[Union[str, Path]] = None,
+    ) -> None:
         """Call this to embed pw console at the call point within your program.
 
         Example usage:
@@ -119,8 +124,9 @@ class PwConsoleEmbed:
         self.repl_startup_message = repl_startup_message
         self.help_text = help_text
         self.app_title = app_title
-        self.config_file_path = Path(
-            config_file_path) if config_file_path else None
+        self.config_file_path = (
+            Path(config_file_path) if config_file_path else None
+        )
 
         self.console_app: Optional[ConsoleApp] = None
         self.extra_completers: List = []
@@ -128,8 +134,7 @@ class PwConsoleEmbed:
         self.setup_python_logging_called = False
         self.hidden_by_default_windows: List[str] = []
         self.window_plugins: List[WindowPane] = []
-        self.floating_window_plugins: List[Tuple[FloatingWindowPane,
-                                                 Dict]] = []
+        self.floating_window_plugins: List[Tuple[FloatingWindowPane, Dict]] = []
         self.top_toolbar_plugins: List[WindowPaneToolbar] = []
         self.bottom_toolbar_plugins: List[WindowPaneToolbar] = []
 
@@ -141,8 +146,9 @@ class PwConsoleEmbed:
         """
         self.window_plugins.append(window_pane)
 
-    def add_floating_window_plugin(self, window_pane: FloatingWindowPane,
-                                   **float_args) -> None:
+    def add_floating_window_plugin(
+        self, window_pane: FloatingWindowPane, **float_args
+    ) -> None:
         """Include a custom floating window pane plugin.
 
         This adds a FloatingWindowPane class to the pw_console UI. The first
@@ -198,9 +204,9 @@ class PwConsoleEmbed:
         """
         self.bottom_toolbar_plugins.append(toolbar)
 
-    def add_sentence_completer(self,
-                               word_meta_dict: Dict[str, str],
-                               ignore_case=True) -> None:
+    def add_sentence_completer(
+        self, word_meta_dict: Dict[str, str], ignore_case=True
+    ) -> None:
         """Include a custom completer that matches on the entire repl input.
 
         Args:
@@ -237,16 +243,20 @@ class PwConsoleEmbed:
         elif isinstance(self.loggers, dict):
             for window_title, logger_instances in self.loggers.items():
                 window_pane = self.console_app.add_log_handler(
-                    window_title, logger_instances)
+                    window_title, logger_instances
+                )
 
-                if (window_pane and window_pane.pane_title()
-                        in self.hidden_by_default_windows):
+                if (
+                    window_pane
+                    and window_pane.pane_title()
+                    in self.hidden_by_default_windows
+                ):
                     window_pane.show_pane = False
 
     def setup_python_logging(
         self,
         last_resort_filename: Optional[str] = None,
-        loggers_with_no_propagation: Optional[Iterable[logging.Logger]] = None
+        loggers_with_no_propagation: Optional[Iterable[logging.Logger]] = None,
     ) -> None:
         """Setup friendly logging for full-screen prompt_toolkit applications.
 
@@ -273,8 +283,9 @@ class PwConsoleEmbed:
                logger.
         """
         self.setup_python_logging_called = True
-        pw_console.python_logging.setup_python_logging(
-            last_resort_filename, loggers_with_no_propagation)
+        pw_console_setup_python_logging(
+            last_resort_filename, loggers_with_no_propagation
+        )
 
     def hide_windows(self, *window_titles) -> None:
         """Hide window panes specified by title on console startup."""
@@ -351,5 +362,6 @@ class PwConsoleEmbed:
                 toolbar.plugin_start()
 
         # Start the prompt_toolkit UI app.
-        asyncio.run(self.console_app.run(test_mode=self.test_mode),
-                    debug=self.test_mode)
+        asyncio.run(
+            self.console_app.run(test_mode=self.test_mode), debug=self.test_mode
+        )
