@@ -183,6 +183,11 @@ class LogContentControl(UIControl):
             """Select next log line."""
             self.log_view.visual_select_down()
 
+        @register('log-pane.visual-select-all', key_bindings)
+        def _select_all_logs(_event: KeyPressEvent) -> None:
+            """Select all log lines."""
+            self.log_pane.log_view.visual_select_all()
+
         @register('log-pane.scroll-page-up', key_bindings)
         def _pageup(_event: KeyPressEvent) -> None:
             """Scroll the logs up by one page."""
@@ -213,11 +218,6 @@ class LogContentControl(UIControl):
             """Previous search match."""
             self.log_view.search_backwards()
 
-        @register('log-pane.visual-select-all', key_bindings)
-        def _select_all_logs(_event: KeyPressEvent) -> None:
-            """Clear search."""
-            self.log_pane.log_view.visual_select_all()
-
         @register('log-pane.deselect-cancel-search', key_bindings)
         def _clear_search_and_selection(_event: KeyPressEvent) -> None:
             """Clear selection or search."""
@@ -290,7 +290,6 @@ class LogContentControl(UIControl):
             mouse_event.event_type == MouseEventType.MOUSE_UP
             and mouse_event.button == MouseButton.LEFT
         ):
-
             # If a drag was in progress and this is the first mouse release
             # press, set the stop flag.
             if (
