@@ -13,7 +13,6 @@
 # the License.
 """Functions for building code during presubmit checks."""
 
-import collections
 import contextlib
 import itertools
 import json
@@ -23,6 +22,7 @@ from pathlib import Path
 import re
 import subprocess
 from shutil import which
+import sys
 from typing import (
     Any,
     Callable,
@@ -40,7 +40,6 @@ from typing import (
     Union,
 )
 
-from pw_package import package_manager
 from pw_presubmit import (
     bazel_parser,
     call,
@@ -48,6 +47,7 @@ from pw_presubmit import (
     FileFilter,
     filter_paths,
     format_code,
+    install_package,
     Iterator,
     log_run,
     ninja_parser,
@@ -103,23 +103,6 @@ def bazel(ctx: PresubmitContext, cmd: str, *args: str) -> None:
         raise exc
 
 
-def install_package(
-    ctx: PresubmitContext, name: str, force: bool = False
-) -> None:
-    """Install package with given name in given path."""
-    root = ctx.package_root
-    mgr = package_manager.PackageManager(root)
-
-    if not mgr.list():
-        raise PresubmitFailure(
-            'no packages configured, please import your pw_package '
-            'configuration module'
-        )
-
-    if not mgr.status(name) or force:
-        mgr.install(name, force=force)
-
-
 def _gn_value(value) -> str:
     if isinstance(value, bool):
         return str(value).lower()
@@ -241,14 +224,21 @@ def ninja(
     ninja_stdout = ctx.output_dir / 'ninja.stdout'
     try:
         with ninja_stdout.open('w') as outs:
+            if sys.platform == 'win32':
+                # Windows doesn't support pw-wrap-ninja.
+                ninja_command = ['ninja']
+            else:
+                ninja_command = ['pw-wrap-ninja', '--log-actions']
+
             call(
-                'ninja',
+                *ninja_command,
                 '-C',
                 ctx.output_dir,
                 *num_jobs,
                 *keep_going,
                 *args,
                 tee=outs,
+                propagate_sigterm=True,
                 **kwargs,
             )
 
@@ -378,6 +368,95 @@ def check_compile_commands_for_files(
     return [f for f in files if f not in compiled and f.suffix in extensions]
 
 
+def check_bazel_build_for_files(
+    bazel_extensions_to_check: Container[str],
+    files: Iterable[Path],
+    bazel_dirs: Iterable[Path] = (),
+) -> List[Path]:
+    """Checks that source files are in the Bazel builds.
+
+    Args:
+        bazel_extensions_to_check: which file suffixes to look for in Bazel
+        files: the files that should be checked
+        bazel_dirs: directories in which to run bazel query
+
+    Returns:
+        a list of missing files; will be empty if there were no missing files
+    """
+
+    # Collect all paths in the Bazel builds.
+    bazel_builds: Set[Path] = set()
+    for directory in bazel_dirs:
+        bazel_builds.update(
+            _get_paths_from_command(
+                directory, 'bazel', 'query', 'kind("source file", //...:*)'
+            )
+        )
+
+    missing: List[Path] = []
+
+    if bazel_dirs:
+        for path in (p for p in files if p.suffix in bazel_extensions_to_check):
+            if path not in bazel_builds:
+                # TODO(b/234883555) Replace this workaround for fuzzers.
+                if 'fuzz' not in str(path):
+                    missing.append(path)
+
+    if missing:
+        _LOG.warning(
+            '%s missing from the Bazel build:\n%s',
+            plural(missing, 'file', are=True),
+            '\n'.join(str(x) for x in missing),
+        )
+
+    return missing
+
+
+def check_gn_build_for_files(
+    gn_extensions_to_check: Container[str],
+    files: Iterable[Path],
+    gn_dirs: Iterable[Tuple[Path, Path]] = (),
+    gn_build_files: Iterable[Path] = (),
+) -> List[Path]:
+    """Checks that source files are in the GN build.
+
+    Args:
+        gn_extensions_to_check: which file suffixes to look for in GN
+        files: the files that should be checked
+        gn_dirs: (source_dir, output_dir) tuples with which to run gn desc
+        gn_build_files: paths to BUILD.gn files to directly search for paths
+
+    Returns:
+        a list of missing files; will be empty if there were no missing files
+    """
+
+    # Collect all paths in GN builds.
+    gn_builds: Set[Path] = set()
+
+    for source_dir, output_dir in gn_dirs:
+        gn_builds.update(
+            _get_paths_from_command(source_dir, 'gn', 'desc', output_dir, '*')
+        )
+
+    gn_builds.update(_search_files_for_paths(gn_build_files))
+
+    missing: List[Path] = []
+
+    if gn_dirs or gn_build_files:
+        for path in (p for p in files if p.suffix in gn_extensions_to_check):
+            if path not in gn_builds:
+                missing.append(path)
+
+    if missing:
+        _LOG.warning(
+            '%s missing from the GN build:\n%s',
+            plural(missing, 'file', are=True),
+            '\n'.join(str(x) for x in missing),
+        )
+
+    return missing
+
+
 def check_builds_for_files(
     bazel_extensions_to_check: Container[str],
     gn_extensions_to_check: Container[str],
@@ -401,48 +480,24 @@ def check_builds_for_files(
         files; will be empty if there were no missing files
     """
 
-    # Collect all paths in the Bazel builds.
-    bazel_builds: Set[Path] = set()
-    for directory in bazel_dirs:
-        bazel_builds.update(
-            _get_paths_from_command(
-                directory, 'bazel', 'query', 'kind("source file", //...:*)'
-            )
-        )
+    bazel_missing = check_bazel_build_for_files(
+        bazel_extensions_to_check=bazel_extensions_to_check,
+        files=files,
+        bazel_dirs=bazel_dirs,
+    )
+    gn_missing = check_gn_build_for_files(
+        gn_extensions_to_check=gn_extensions_to_check,
+        files=files,
+        gn_dirs=gn_dirs,
+        gn_build_files=gn_build_files,
+    )
 
-    # Collect all paths in GN builds.
-    gn_builds: Set[Path] = set()
-
-    for source_dir, output_dir in gn_dirs:
-        gn_builds.update(
-            _get_paths_from_command(source_dir, 'gn', 'desc', output_dir, '*')
-        )
-
-    gn_builds.update(_search_files_for_paths(gn_build_files))
-
-    missing: Dict[str, List[Path]] = collections.defaultdict(list)
-
-    if bazel_dirs:
-        for path in (p for p in files if p.suffix in bazel_extensions_to_check):
-            if path not in bazel_builds:
-                # TODO(b/234883555) Replace this workaround for fuzzers.
-                if 'fuzz' not in str(path):
-                    missing['Bazel'].append(path)
-
-    if gn_dirs or gn_build_files:
-        for path in (p for p in files if p.suffix in gn_extensions_to_check):
-            if path not in gn_builds:
-                missing['GN'].append(path)
-
-    for builder, paths in missing.items():
-        _LOG.warning(
-            '%s missing from the %s build:\n%s',
-            plural(paths, 'file', are=True),
-            builder,
-            '\n'.join(str(x) for x in paths),
-        )
-
-    return missing
+    result = {}
+    if bazel_missing:
+        result['Bazel'] = bazel_missing
+    if gn_missing:
+        result['GN'] = gn_missing
+    return result
 
 
 @contextlib.contextmanager
@@ -465,7 +520,7 @@ def test_server(executable: str, output_dir: Path):
             yield
 
         finally:
-            proc.terminate()
+            proc.terminate()  # pylint: disable=used-before-assignment
 
 
 @filter_paths(
@@ -594,11 +649,8 @@ class GnGenNinja(Check):
     ) -> PresubmitResult:
         with contextlib.ExitStack() as stack:
             for mgr in self.ninja_contexts:
-                # hasattr(x, '__enter__') can return True for types, so
-                # explicitly exclude them. Only non-type objects can be
-                # context managers.
-                if hasattr(mgr, '__enter__') and not isinstance(mgr, type):
-                    stack.enter_context(mgr)  # type: ignore
+                if isinstance(mgr, contextlib.AbstractContextManager):
+                    stack.enter_context(mgr)
                 else:
                     stack.enter_context(mgr(ctx))  # type: ignore
             ninja(ctx, *targets)
