@@ -50,7 +50,6 @@ from typing import (
     Dict,
     List,
     Iterable,
-    IO,
     Iterator,
     Match,
     NamedTuple,
@@ -74,6 +73,8 @@ ENCODED_TOKEN = struct.Struct('<I')
 BASE64_PREFIX = encode.BASE64_PREFIX.encode()
 DEFAULT_RECURSION = 9
 
+_RawIO = Union[io.RawIOBase, BinaryIO]
+
 
 class DetokenizedString:
     """A detokenized string, with all results if there are collisions."""
@@ -265,7 +266,7 @@ class Detokenizer:
 
     def detokenize_base64_live(
         self,
-        input_file: BinaryIO,
+        input_file: _RawIO,
         output: BinaryIO,
         prefix: Union[str, bytes] = BASE64_PREFIX,
         recursion: int = DEFAULT_RECURSION,
@@ -319,7 +320,28 @@ class Detokenizer:
         return decode_and_detokenize
 
 
-_PathOrFile = Union[IO, str, Path]
+_PathOrStr = Union[Path, str]
+
+
+# TODO(b/265334753): Reuse this function in database.py:LoadTokenDatabases
+def _parse_domain(path: _PathOrStr) -> Tuple[Path, Optional[Pattern[str]]]:
+    """Extracts an optional domain regex pattern suffix from a path"""
+
+    if isinstance(path, Path):
+        path = str(path)
+
+    delimiters = path.count('#')
+
+    if delimiters == 0:
+        return Path(path), None
+
+    if delimiters == 1:
+        path, domain = path.split('#')
+        return Path(path), re.compile(domain)
+
+    raise ValueError(
+        f'Too many # delimiters. Expected 0 or 1, found {delimiters}'
+    )
 
 
 class AutoUpdatingDetokenizer(Detokenizer):
@@ -328,18 +350,8 @@ class AutoUpdatingDetokenizer(Detokenizer):
     class _DatabasePath:
         """Tracks the modified time of a path or file object."""
 
-        def __init__(self, path: _PathOrFile) -> None:
-            self.path: Path
-            self.domain = None
-            if isinstance(path, str):
-                if path.count('#') == 1:
-                    path, domain = path.split('#')
-                    self.domain = re.compile(domain)
-                self.path = Path(path)
-            elif isinstance(path, Path):
-                self.path = path
-            else:
-                self.path = Path(path.name)
+        def __init__(self, path: _PathOrStr) -> None:
+            self.path, self.domain = _parse_domain(path)
             self._modified_time: Optional[float] = self._last_modified_time()
 
         def updated(self) -> bool:
@@ -368,7 +380,7 @@ class AutoUpdatingDetokenizer(Detokenizer):
                 return database.load_token_database()
 
     def __init__(
-        self, *paths_or_files: _PathOrFile, min_poll_period_s: float = 1.0
+        self, *paths_or_files: _PathOrStr, min_poll_period_s: float = 1.0
     ) -> None:
         self.paths = tuple(self._DatabasePath(path) for path in paths_or_files)
         self.min_poll_period_s = min_poll_period_s
@@ -418,16 +430,14 @@ class PrefixedMessageDecoder:
 
         self.data = bytearray()
 
-    def _read_next(self, fd: BinaryIO) -> Tuple[bytes, int]:
+    def _read_next(self, fd: _RawIO) -> Tuple[bytes, int]:
         """Returns the next character and its index."""
-        char = fd.read(1)
+        char = fd.read(1) or b''
         index = len(self.data)
         self.data += char
         return char, index
 
-    def read_messages(
-        self, binary_fd: BinaryIO
-    ) -> Iterator[Tuple[bool, bytes]]:
+    def read_messages(self, binary_fd: _RawIO) -> Iterator[Tuple[bool, bytes]]:
         """Parses prefixed messages; yields (is_message, contents) chunks."""
         message_start = None
 
@@ -454,7 +464,7 @@ class PrefixedMessageDecoder:
                 yield False, char
 
     def transform(
-        self, binary_fd: BinaryIO, transform: Callable[[bytes], bytes]
+        self, binary_fd: _RawIO, transform: Callable[[bytes], bytes]
     ) -> Iterator[bytes]:
         """Yields the file with a transformation applied to the messages."""
         for is_message, chunk in self.read_messages(binary_fd):
