@@ -41,7 +41,6 @@ from typing import (
 )
 from uuid import uuid4
 
-DATE_FORMAT = '%Y-%m-%d'
 DEFAULT_DOMAIN = ''
 
 # The default hash length to use for C-style hashes. This value only applies
@@ -355,24 +354,26 @@ class Database:
 
 def parse_csv(fd: TextIO) -> Iterable[TokenizedStringEntry]:
     """Parses TokenizedStringEntries from a CSV token database file."""
+    entries = []
     for line in csv.reader(fd):
         try:
             token_str, date_str, string_literal = line
 
             token = int(token_str, 16)
             date = (
-                datetime.strptime(date_str, DATE_FORMAT)
-                if date_str.strip()
-                else None
+                datetime.fromisoformat(date_str) if date_str.strip() else None
             )
 
-            yield TokenizedStringEntry(
-                token, string_literal, DEFAULT_DOMAIN, date
+            entries.append(
+                TokenizedStringEntry(
+                    token, string_literal, DEFAULT_DOMAIN, date
+                )
             )
         except (ValueError, UnicodeDecodeError) as err:
             _LOG.error(
                 'Failed to parse tokenized string entry %s: %s', line, err
             )
+    return entries
 
 
 def write_csv(database: Database, fd: BinaryIO) -> None:
@@ -388,9 +389,7 @@ def _write_csv_line(fd: BinaryIO, entry: TokenizedStringEntry):
     fd.write(
         '{:08x},{:10},"{}"\n'.format(
             entry.token,
-            entry.date_removed.strftime(DATE_FORMAT)
-            if entry.date_removed
-            else '',
+            entry.date_removed.date().isoformat() if entry.date_removed else '',
             entry.string.replace('"', '""'),
         ).encode()
     )  # escape " as ""
@@ -546,8 +545,7 @@ class DatabaseFile(Database):
 
         # Read the path as a CSV file.
         _check_that_file_is_csv_database(path)
-        with path.open('r', newline='', encoding='utf-8') as csv_fd:
-            return _CSVDatabase(path, csv_fd)
+        return _CSVDatabase(path)
 
     @abstractmethod
     def write_to_file(self, *, rewrite: bool = False) -> None:
@@ -586,8 +584,9 @@ class _BinaryDatabase(DatabaseFile):
 
 
 class _CSVDatabase(DatabaseFile):
-    def __init__(self, path: Path, fd: TextIO) -> None:
-        super().__init__(path, parse_csv(fd))
+    def __init__(self, path: Path) -> None:
+        with path.open('r', newline='', encoding='utf-8') as csv_fd:
+            super().__init__(path, parse_csv(csv_fd))
 
     def write_to_file(self, *, rewrite: bool = False) -> None:
         """Exports in the CSV format to the original path."""
@@ -614,8 +613,7 @@ _DIR_DB_GLOB = '*' + DIR_DB_SUFFIX
 def _parse_directory(directory: Path) -> Iterable[TokenizedStringEntry]:
     """Parses TokenizedStringEntries tokenizer CSV files in the directory."""
     for path in directory.glob(_DIR_DB_GLOB):
-        with path.open() as fd:
-            yield from parse_csv(fd)
+        yield from _CSVDatabase(path).entries()
 
 
 def _most_recently_modified_file(paths: Iterable[Path]) -> Path:
